@@ -7,7 +7,7 @@ from typing import Callable
 import redis
 
 from pymq import RpcRequest
-from pymq.core import Queue, Empty
+from pymq.core import Empty, Queue
 from pymq.json import DeepDictDecoder, DeepDictEncoder
 from pymq.provider.base import AbstractEventBus, DefaultSkeletonMethod, invoke_function
 
@@ -15,7 +15,6 @@ logger = logging.getLogger(__name__)
 
 
 class RedisConfig:
-
     def __init__(self, *args, **kwargs) -> None:
         super().__init__()
 
@@ -49,13 +48,16 @@ class RedisQueue(Queue):
     def get(self, block=True, timeout=None):
         if block:
             response = self._rds.brpop(self._key, timeout)
+            if response is None:
+                raise Empty
+            response = response[1]
         else:
             response = self._rds.rpop(self._key)
 
         if response is None:
             raise Empty
 
-        return self._deserialize(response[1])
+        return self._deserialize(response)
 
     def put(self, item, block=False, timeout=None):
         if block:
@@ -81,13 +83,15 @@ class RedisSkeletonMethod(DefaultSkeletonMethod):
     # noinspection PyUnresolvedReferences
     def _queue_response(self, request, response):
         super()._queue_response(request, response)
-        self._bus.rds.expire(self._bus.channel_prefix + request.response_channel, self._bus.rpc_channel_expire)
+        self._bus.rds.expire(
+            self._bus.channel_prefix + request.response_channel, self._bus.rpc_channel_expire
+        )
 
 
 class RedisEventBus(AbstractEventBus):
     rpc_channel_expire = 300  # 5 minute default
 
-    def __init__(self, namespace='global', dispatcher=None, rds: redis.Redis = None) -> None:
+    def __init__(self, namespace="global", dispatcher=None, rds: redis.Redis = None) -> None:
         super().__init__()
         self.namespace = namespace
         self.dispatcher: ThreadPoolExecutor = dispatcher
@@ -97,26 +101,26 @@ class RedisEventBus(AbstractEventBus):
         self._lock = threading.Condition()
         self._closed = False
 
-        self.channel_prefix = '__eventbus:' + self.namespace + ":"
+        self.channel_prefix = "__eventbus:" + self.namespace + ":"
 
     def _listen(self):
         while True:
             if not self._pubsub:
-                logger.error('invalid state, pubsub object is not set')
+                logger.error("invalid state, pubsub object is not set")
                 return
 
-            logger.debug('waiting for subscriptions to appear')
+            logger.debug("waiting for subscriptions to appear")
             with self._lock:
                 self._lock.wait_for(lambda: self._pubsub.subscribed or self._closed)
 
             if self._closed:
-                logger.debug('eventbus closed, listening stops')
+                logger.debug("eventbus closed, listening stops")
                 return
 
-            logger.debug('subscriptions available starting to listen on pubsub object')
+            logger.debug("subscriptions available starting to listen on pubsub object")
 
             yield from self._pubsub.listen()
-            logger.debug('pubsub listen returned, waiting on next iteration')
+            logger.debug("pubsub listen returned, waiting on next iteration")
 
     def run(self):
         with self._lock:
@@ -132,39 +136,39 @@ class RedisEventBus(AbstractEventBus):
             self._lock.notify()
 
         try:
-            logger.debug('starting to listen on pubsub...')
+            logger.debug("starting to listen on pubsub...")
             for message in self._listen():
-                logger.debug('got message %s', message)
+                logger.debug("got message %s", message)
 
-                if not (message['type'] == 'message' or message['type'] == 'pmessage'):
+                if not (message["type"] == "message" or message["type"] == "pmessage"):
                     continue
 
-                if message['pattern'] is None:
-                    key = (message['channel'], False)
+                if message["pattern"] is None:
+                    key = (message["channel"], False)
                 else:
-                    key = (message['pattern'], True)
+                    key = (message["pattern"], True)
 
-                key = key[0][len(self.channel_prefix):], key[1]
+                key = key[0][len(self.channel_prefix) :], key[1]
 
                 if key not in self._subscribers:
-                    logger.warning('inconsistent state: no listeners for %s', key)
+                    logger.warning("inconsistent state: no listeners for %s", key)
                     continue
 
                 for fn in self._subscribers[key]:
-                    logger.debug('dispatching %s to %s', message, fn)
+                    logger.debug("dispatching %s to %s", message, fn)
 
-                    self.dispatcher.submit(RedisEventBus._call_listener, fn, message['data'])
+                    self.dispatcher.submit(RedisEventBus._call_listener, fn, message["data"])
 
         except Exception as listen_error:
             logger.error(listen_error)
 
         finally:
-            logger.debug('acquiring close lock')
+            logger.debug("acquiring close lock")
             with self._lock:
-                logger.debug('closing pubsub')
+                logger.debug("closing pubsub")
                 self._pubsub.close()
 
-        logger.debug('exitting eventbus listen loop')
+        logger.debug("exitting eventbus listen loop")
 
     def subscribe(self, callback, channel=None, pattern=False):
         with self._lock:
@@ -183,15 +187,15 @@ class RedisEventBus(AbstractEventBus):
 
             self._closed = True
 
-            logger.debug('unsubscribing from all channels')
+            logger.debug("unsubscribing from all channels")
             self._pubsub.punsubscribe()
             self._pubsub.unsubscribe()
 
             self._lock.notify()
 
-        logger.debug('shutting down dispatcher')
+        logger.debug("shutting down dispatcher")
         self.dispatcher.shutdown()
-        logger.debug('shutdown complete')
+        logger.debug("shutdown complete")
 
     def queue(self, name: str) -> Queue:
         return RedisQueue(self.rds, name, self.channel_prefix + name)
@@ -236,15 +240,23 @@ class RedisEventBus(AbstractEventBus):
                 self._pubsub.unsubscribe(redis_channel)
 
     def _init_subscriptions(self):
-        logger.debug('initializing subscriptions %s', self._subscribers)
-        channels = [self.channel_prefix + channel for channel, pattern in self._subscribers.keys() if not pattern]
-        patterns = [self.channel_prefix + channel for channel, pattern in self._subscribers.keys() if pattern]
+        logger.debug("initializing subscriptions %s", self._subscribers)
+        channels = [
+            self.channel_prefix + channel
+            for channel, pattern in self._subscribers.keys()
+            if not pattern
+        ]
+        patterns = [
+            self.channel_prefix + channel
+            for channel, pattern in self._subscribers.keys()
+            if pattern
+        ]
 
         if channels:
-            logger.debug('initializing channel subscriptions %s', channels)
+            logger.debug("initializing channel subscriptions %s", channels)
             self._pubsub.subscribe(*channels)
         if patterns:
-            logger.debug('initializing pattern subscriptions %s', patterns)
+            logger.debug("initializing pattern subscriptions %s", patterns)
             self._pubsub.psubscribe(*patterns)
 
     @staticmethod
